pub struct Workspace { /* private fields */ }Expand description
The project workspace.
It contains all modules imported and validates them against each other.
Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn add_local_module(&mut self, module_path: &str, module: File)
pub fn add_local_module(&mut self, module_path: &str, module: File)
Adds a new local module to the workspace.
Sourcepub fn validate(&mut self) -> Result<(), ParserError>
pub fn validate(&mut self) -> Result<(), ParserError>
Validates all modules in the workspace.
This function is fail-fast. Meaning, it will fail at each first error it founds.
Sourcepub fn package_local_modules(&self) -> &HashMap<String, File>
pub fn package_local_modules(&self) -> &HashMap<String, File>
Gets a reference to the local modules in the workspace.